@@ -22,6 +22,6 @@ ModelDataT = TypeVar("ModelDataT", bound=BaseModel)
 
 
 class PingData(BaseModel):
-    message: Annotated[Literal["pong"], Field("pong", description="Ping response")] = (
+    ping: Annotated[Literal["pong"], Field("pong", description="Ping response")] = (
         "pong"
     )
