@@ -43,14 +43,14 @@ from ..operation.request import (
     ReadFailedRequestOperation,
     UpdateFailedRequestOperation,
     DeleteFailedRequestOperation,
-    FailedFactory as FailedRequestOperationFactory,
+    FailedRequestOperationFactory,
 )
 from ..operation.resource import (
     CreateFailedResourceOperation,
     ReadFailedResourceOperation,
     UpdateFailedResourceOperation,
     DeleteFailedResourceOperation,
-    FailedFactory as FailedResourceOperationFactory,
+    FailedResourceOperationFactory,
 )
 from ..operation.system import FailedSystemOperation
 from ..operation.websocket import FailedWebSocketOperation
