@@ -28,7 +28,7 @@ from ..response import (
     OptBadGatewayResponse,
     OptServiceUnavailableResponse,
     OptAnyErrorResponse,
-    ErrorFactory as ErrorResponseFactory,
+    ErrorResponseFactory,
 )
 from ..security.authentication import OptAnyAuthentication
 from ..security.authorization import OptAnyAuthorization
