@@ -11,7 +11,6 @@ from fastapi.requests import HTTPConnection
 from fastapi.responses import JSONResponse
 from pydantic import ValidationError
 from starlette.authentication import AuthenticationError
-from maleo.logging.enums import Level
 from maleo.logging.logger import EnvironmentT, ServiceKeyT, Exception as ExceptionLogger
 from maleo.utils.exception import extract_details
 from ..error.constants import ERROR_CODE_STATUS_CODE_MAP
@@ -21,7 +20,7 @@ from ..response import (
     UnauthorizedResponse,
     UnprocessableEntityResponse,
     InternalServerErrorResponse,
-    ErrorFactory as ErrorResponseFactory,
+    ErrorResponseFactory,
 )
 from .exc import MaleoException, AnyException
 
@@ -72,7 +71,7 @@ def create_maleo_exception_handler(
     async def maleo_exception_handler(
         request: Request, exc: MaleoException | AnyException
     ) -> JSONResponse:
-        exc.log_and_publish_operation(logger, Level.ERROR, publishers)
+        exc.log_and_publish_operation(logger, publishers)
 
         return JSONResponse(
             content=exc.response.model_dump(mode="json"),
