@@ -2,7 +2,7 @@ from pydantic import BaseModel, Field
 from typing import Annotated, Generic, TypeVar
 from uuid import UUID as PythonUUID
 from maleo.types.datetime import OptDateT, OptListOfDatesT
-from maleo.types.enum import StrEnumT
+from maleo.types.enum import StrEnumT, OptStrEnumT
 from maleo.types.integer import OptIntT, OptListOfIntsT
 from maleo.types.misc import (
     OptIntOrUUIDT,
@@ -31,10 +31,11 @@ class Identifier(
     pass
 
 
-class IdentifierMixin(BaseModel, Generic[StrEnumT, IdentifierValueT]):
-    identifier: Annotated[
-        Identifier[StrEnumT, IdentifierValueT], Field(..., description="Identifier")
-    ]
+IdentifierT = TypeVar("IdentifierT", bound=Identifier)
+
+
+class IdentifierMixin(BaseModel, Generic[IdentifierT]):
+    identifier: Annotated[IdentifierT, Field(..., description="Identifier")]
 
 
 # Id
@@ -80,16 +81,17 @@ class DataIdentifier(
     pass
 
 
+class EntityType(BaseModel, Generic[OptStrEnumT]):
+    type: Annotated[OptStrEnumT, Field(..., description="Entity's type")]
+
+
 class EntityIdentifier(
-    UUID[PythonUUID],
-    IntId[int],
+    EntityType[OptStrEnumT], UUID[PythonUUID], IntId[int], Generic[OptStrEnumT]
 ):
     pass
 
 
 EntityIdentifierT = TypeVar("EntityIdentifierT", bound=EntityIdentifier)
-OptEntityIdentifier = EntityIdentifier | None
-OptEntityIdentifierT = TypeVar("OptEntityIdentifierT", bound=OptEntityIdentifier)
 
 
 class IdCard(BaseModel, Generic[OptStrT]):
