@@ -3,7 +3,7 @@ from fastapi.requests import HTTPConnection
 from typing import Callable
 from uuid import UUID
 from maleo.enums.connection import Header as HeaderEnum
-from maleo.types.uuid import OptionalUUID
+from maleo.types.uuid import OptUUID
 from .enums import IdSource
 from .extractor import extract_operation_id
 
@@ -15,7 +15,7 @@ def get_operation_id(
     def dependency(
         conn: HTTPConnection,
         # the following operation_id is for documentation purpose only
-        operation_id: OptionalUUID = Header(
+        _operation_id: OptUUID = Header(
             None,
             alias=HeaderEnum.X_OPERATION_ID.value,
             description="Operation's ID",
