@@ -77,18 +77,6 @@ class ResourceOperationType(StrEnum):
 OptResourceOperationType = ResourceOperationType | None
 
 
-class ResourceOperationCreateType(StrEnum):
-    NEW = "new"
-    RESTORE = "restore"
-
-    @classmethod
-    def choices(cls) -> ListOfStrs:
-        return [e.value for e in cls]
-
-
-OptResourceOperationCreateType = ResourceOperationCreateType | None
-
-
 class ResourceOperationUpdateType(StrEnum):
     DATA = "data"
     STATUS = "status"
