@@ -1,20 +1,21 @@
-from fastapi import status, HTTPException, Request
+from fastapi import status, HTTPException
+from fastapi.requests import HTTPConnection
 from uuid import UUID, uuid4
 from maleo.enums.connection import Header
 from .enums import IdSource
 
 
 def extract_operation_id(
-    source: IdSource = IdSource.STATE, *, request: Request, generate: bool = False
+    source: IdSource = IdSource.STATE, *, conn: HTTPConnection, generate: bool = False
 ) -> UUID:
     if source is IdSource.HEADER:
-        operation_id = request.headers.get(Header.X_OPERATION_ID.value, None)
+        operation_id = conn.headers.get(Header.X_OPERATION_ID.value, None)
         try:
             operation_id = UUID(operation_id)
         except Exception:
             pass
     elif source is IdSource.STATE:
-        operation_id = request.state.operation_id
+        operation_id = getattr(conn.state, "operation_id", None)
     if operation_id is not None and not isinstance(operation_id, UUID):
         raise HTTPException(
             status_code=status.HTTP_400_BAD_REQUEST,
@@ -26,7 +27,7 @@ def extract_operation_id(
 
     if generate:
         operation_id = uuid4()
-        request.state.operation_id = operation_id
+        conn.state.operation_id = operation_id
         return operation_id
 
     raise HTTPException(
