@@ -32,7 +32,6 @@ from .enums import (
     OperationType,
     ResourceOperationType,
     OptResourceOperationType,
-    OptResourceOperationCreateType,
     OptResourceOperationUpdateType,
     OptResourceOperationDataUpdateType,
     OptResourceOperationStatusUpdateType,
@@ -188,7 +187,7 @@ AnySuccessfulRequestOperation = (
 )
 
 
-class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
+class FailedRequestOperationFactory(Generic[AnyErrorT, ErrorResponseT]):
     @overload
     @classmethod
     def operation_cls_from_action(cls, action: CreateResourceOperationAction) -> Type[
@@ -512,7 +511,6 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         cls,
         *,
         type_: Literal[ResourceOperationType.CREATE],
-        create_type: OptResourceOperationCreateType = ...,
         application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
@@ -592,7 +590,6 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         cls,
         *,
         type_: ResourceOperationType,
-        create_type: OptResourceOperationCreateType = None,
         update_type: OptResourceOperationUpdateType = None,
         data_update_type: OptResourceOperationDataUpdateType = None,
         status_update_type: OptResourceOperationStatusUpdateType = None,
@@ -632,7 +629,6 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         action: OptAnyResourceOperationAction = None,
         *,
         type_: OptResourceOperationType = None,
-        create_type: OptResourceOperationCreateType = None,
         update_type: OptResourceOperationUpdateType = None,
         data_update_type: OptResourceOperationDataUpdateType = None,
         status_update_type: OptResourceOperationStatusUpdateType = None,
@@ -698,7 +694,6 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         elif type_ is not None:
             action = ResourceOperationActionFactory.generate(
                 type_,
-                create_type=create_type,
                 update_type=update_type,
                 data_update_type=data_update_type,
                 status_update_type=status_update_type,
@@ -887,7 +882,6 @@ class SuccessfulFactory:
         cls,
         *,
         type_: Literal[ResourceOperationType.CREATE],
-        create_type: OptResourceOperationCreateType = ...,
         application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
@@ -963,7 +957,6 @@ class SuccessfulFactory:
         cls,
         *,
         type_: ResourceOperationType,
-        create_type: OptResourceOperationCreateType = None,
         update_type: OptResourceOperationUpdateType = None,
         data_update_type: OptResourceOperationDataUpdateType = None,
         status_update_type: OptResourceOperationStatusUpdateType = None,
@@ -985,7 +978,6 @@ class SuccessfulFactory:
         action: OptAnyResourceOperationAction = None,
         *,
         type_: OptResourceOperationType = None,
-        create_type: OptResourceOperationCreateType = None,
         update_type: OptResourceOperationUpdateType = None,
         data_update_type: OptResourceOperationDataUpdateType = None,
         status_update_type: OptResourceOperationStatusUpdateType = None,
@@ -1032,7 +1024,6 @@ class SuccessfulFactory:
         if type_ is not None:
             action = ResourceOperationActionFactory.generate(
                 type_,
-                create_type=create_type,
                 update_type=update_type,
                 data_update_type=data_update_type,
                 status_update_type=status_update_type,
