@@ -43,7 +43,6 @@ from .enums import (
     OperationType,
     ResourceOperationType,
     OptResourceOperationType,
-    OptResourceOperationCreateType,
     OptResourceOperationUpdateType,
     OptResourceOperationDataUpdateType,
     OptResourceOperationStatusUpdateType,
@@ -281,7 +280,7 @@ class DeleteMultipleResourceOperation(
     pass
 
 
-class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
+class FailedResourceOperationFactory(Generic[AnyErrorT, ErrorResponseT]):
     @overload
     @classmethod
     def operation_cls_from_action(cls, action: CreateResourceOperationAction) -> Type[
@@ -605,7 +604,6 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         cls,
         *,
         type_: Literal[ResourceOperationType.CREATE],
-        create_type: OptResourceOperationCreateType = ...,
         application_context: ApplicationContext,
         id: UUID,
         context: OperationContext,
@@ -685,7 +683,6 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         cls,
         *,
         type_: ResourceOperationType,
-        create_type: OptResourceOperationCreateType = None,
         update_type: OptResourceOperationUpdateType = None,
         data_update_type: OptResourceOperationDataUpdateType = None,
         status_update_type: OptResourceOperationStatusUpdateType = None,
@@ -725,7 +722,6 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         action: OptAnyResourceOperationAction = None,
         *,
         type_: OptResourceOperationType = None,
-        create_type: OptResourceOperationCreateType = None,
         update_type: OptResourceOperationUpdateType = None,
         data_update_type: OptResourceOperationDataUpdateType = None,
         status_update_type: OptResourceOperationStatusUpdateType = None,
@@ -791,7 +787,6 @@ class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
         if type_ is not None:
             action = ResourceOperationActionFactory.generate(
                 type_,
-                create_type=create_type,
                 update_type=update_type,
                 data_update_type=data_update_type,
                 status_update_type=status_update_type,
