@@ -1,13 +1,8 @@
-from pydantic import Field
-from typing import Annotated, Generic
-from maleo.enums.status import (
-    ListOfDataStatuses,
-    SimpleDataStatusesMixin,
-    FULL_DATA_STATUSES,
-)
+from typing import Generic
 from .mixins.filter import DateFilters
 from .mixins.identity import IdentifierMixin, IdentifierT
 from .mixins.parameter import (
+    MandatorySimpleDataStatusesMixin,
     Search,
     UseCache,
 )
@@ -17,31 +12,25 @@ from .pagination import BaseFlexiblePagination, BaseStrictPagination
 
 
 class ReadSingleParameter(
-    SimpleDataStatusesMixin[ListOfDataStatuses],
     UseCache,
+    MandatorySimpleDataStatusesMixin,
     IdentifierMixin[IdentifierT],
     Generic[IdentifierT],
 ):
-    statuses: Annotated[
-        ListOfDataStatuses,
-        Field(FULL_DATA_STATUSES, description="Data statuses", min_length=1),
-    ] = FULL_DATA_STATUSES
+    pass
 
 
 class BaseReadMultipleParameter(
     SortColumns,
     Search,
-    SimpleDataStatusesMixin[ListOfDataStatuses],
+    MandatorySimpleDataStatusesMixin,
     DateFilters,
-    UseCache,
 ):
-    statuses: Annotated[
-        ListOfDataStatuses,
-        Field(FULL_DATA_STATUSES, description="Data statuses", min_length=1),
-    ] = FULL_DATA_STATUSES
+    pass
 
 
 class ReadUnpaginatedMultipleParameter(
+    UseCache,
     BaseFlexiblePagination,
     BaseReadMultipleParameter,
 ):
@@ -49,6 +38,7 @@ class ReadUnpaginatedMultipleParameter(
 
 
 class ReadPaginatedMultipleParameter(
+    UseCache,
     BaseStrictPagination,
     BaseReadMultipleParameter,
 ):
