@@ -268,7 +268,7 @@ OptAnyErrorResponse = AnyErrorResponse | None
 OptErrorResponseT = TypeVar("OptErrorResponseT", bound=OptAnyErrorResponse)
 
 
-class ErrorFactory:
+class ErrorResponseFactory:
     @overload
     @staticmethod
     def cls_from_code(
@@ -510,7 +510,7 @@ class ErrorFactory:
             obj["description"] = description
         if other is not None:
             obj["other"] = other
-        return ErrorFactory.cls_from_code(code).model_validate(obj)
+        return ErrorResponseFactory.cls_from_code(code).model_validate(obj)
 
 
 OTHER_RESPONSES: dict[
