@@ -65,6 +65,43 @@ class TokenV1(BaseModel):
         )
         return cls.model_validate(obj)
 
+    @overload
+    def to_string(
+        self,
+        key: RsaKey,
+    ) -> str: ...
+    @overload
+    def to_string(
+        self,
+        key: BytesOrStr,
+        *,
+        password: OptStr = None,
+    ) -> str: ...
+    @overload
+    def to_string(
+        self,
+        key: BytesOrStr | RsaKey,
+        *,
+        password: OptStr = None,
+    ) -> str: ...
+    def to_string(
+        self,
+        key: BytesOrStr | RsaKey,
+        *,
+        password: OptStr = None,
+    ) -> str:
+        if isinstance(key, RsaKey):
+            return encode(
+                payload=self.model_dump(mode="json", exclude_none=True),
+                key=key,
+            )
+        else:
+            return encode(
+                payload=self.model_dump(mode="json", exclude_none=True),
+                key=key,
+                password=password,
+            )
+
 
 class Claim(BaseModel):
     iss: Annotated[OptStr, Field(None, description="Issuer")] = None
@@ -133,6 +170,13 @@ class GenericToken(
         *,
         password: OptStr = None,
     ) -> str: ...
+    @overload
+    def to_string(
+        self,
+        key: BytesOrStr | RsaKey,
+        *,
+        password: OptStr = None,
+    ) -> str: ...
     def to_string(
         self,
         key: BytesOrStr | RsaKey,
@@ -218,7 +262,7 @@ class TokenMixin(BaseModel, Generic[OptAnyTokenT]):
     token: OptAnyTokenT = Field(..., description="Token")
 
 
-def is_tenant(token: AnyToken) -> TypeGuard[TenantToken]:
+def is_tenant_token(token: AnyToken) -> TypeGuard[TenantToken]:
     return (
         isinstance(token, TenantToken)
         and token.d is Domain.TENANT
@@ -226,13 +270,13 @@ def is_tenant(token: AnyToken) -> TypeGuard[TenantToken]:
     )
 
 
-def is_system(token: AnyToken) -> TypeGuard[SystemToken]:
+def is_system_token(token: AnyToken) -> TypeGuard[SystemToken]:
     return (
         isinstance(token, SystemToken) and token.d is Domain.SYSTEM and token.o is None
     )
 
 
-class Factory:
+class TokenFactory:
     @overload
     @staticmethod
     def from_string(
@@ -345,13 +389,13 @@ class Factory:
         if domain is None:
             return result_token
         elif domain is Domain.TENANT:
-            if not is_tenant(result_token):
+            if not is_tenant_token(result_token):
                 raise ValueError(
                     "Failed parsing Tenant Token from string, raw token did not qualify as Tenant Token"
                 )
             return result_token
         elif domain is Domain.SYSTEM:
-            if not is_system(result_token):
+            if not is_system_token(result_token):
                 raise ValueError(
                     "Failed parsing System token from string, raw token did not qualify as System Token"
                 )
